# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: locapip_test.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='locapip_test.proto',
  package='locapip_test',
  syntax='proto3',
  serialized_options=b'H\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x12locapip_test.proto\x12\x0clocapip_test\"\x14\n\x04Text\x12\x0c\n\x04text\x18\x01 \x01(\t2\xf0\x01\n\x04Test\x12\x37\n\x0bunary_unary\x12\x12.locapip_test.Text\x1a\x12.locapip_test.Text\"\x00\x12\x38\n\x0cunary_stream\x12\x12.locapip_test.Text\x1a\x12.locapip_test.Text0\x01\x12\x38\n\x0cstream_unary\x12\x12.locapip_test.Text\x1a\x12.locapip_test.Text(\x01\x12;\n\rstream_stream\x12\x12.locapip_test.Text\x1a\x12.locapip_test.Text(\x01\x30\x01\x42\x02H\x01\x62\x06proto3'
)




_TEXT = _descriptor.Descriptor(
  name='Text',
  full_name='locapip_test.Text',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='locapip_test.Text.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=36,
  serialized_end=56,
)

DESCRIPTOR.message_types_by_name['Text'] = _TEXT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Text = _reflection.GeneratedProtocolMessageType('Text', (_message.Message,), {
  'DESCRIPTOR' : _TEXT,
  '__module__' : 'locapip_test_pb2'
  # @@protoc_insertion_point(class_scope:locapip_test.Text)
  })
_sym_db.RegisterMessage(Text)


DESCRIPTOR._options = None

_TEST = _descriptor.ServiceDescriptor(
  name='Test',
  full_name='locapip_test.Test',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=59,
  serialized_end=299,
  methods=[
  _descriptor.MethodDescriptor(
    name='unary_unary',
    full_name='locapip_test.Test.unary_unary',
    index=0,
    containing_service=None,
    input_type=_TEXT,
    output_type=_TEXT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='unary_stream',
    full_name='locapip_test.Test.unary_stream',
    index=1,
    containing_service=None,
    input_type=_TEXT,
    output_type=_TEXT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='stream_unary',
    full_name='locapip_test.Test.stream_unary',
    index=2,
    containing_service=None,
    input_type=_TEXT,
    output_type=_TEXT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='stream_stream',
    full_name='locapip_test.Test.stream_stream',
    index=3,
    containing_service=None,
    input_type=_TEXT,
    output_type=_TEXT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TEST)

DESCRIPTOR.services_by_name['Test'] = _TEST

# @@protoc_insertion_point(module_scope)
